# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x08\x64x.proto\x12\x08\x61utocare\"\x07\n\x05\x45mpty\"\x1d\n\x0bPipelineReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\"\x1d\n\x0bPipelineRes\x12\x0e\n\x06result\x18\x01 \x01(\x08\"\xbe\x01\n\x0cInferenceReq\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\t\x12\x16\n\tstream_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03uri\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08settings\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x06offset\x18\x06 \x01(\x03H\x04\x88\x01\x01\x42\x0c\n\n_stream_idB\x06\n\x04_uriB\x0b\n\t_settingsB\x07\n\x05_nameB\t\n\x07_offset\"\xf7\x01\n\x0cInferenceRes\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\x12\x13\n\x06status\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x10\n\x03\x65os\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x10\n\x03\x65rr\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12\x11\n\x04meta\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08snapshot\x18\x06 \x01(\x0cH\x04\x88\x01\x01\x12\x13\n\x06\x61pp_id\x18\x07 \x01(\tH\x05\x88\x01\x01\x12\x16\n\tstream_id\x18\x08 \x01(\tH\x06\x88\x01\x01\x42\t\n\x07_statusB\x06\n\x04_eosB\x06\n\x04_errB\x07\n\x05_metaB\x0b\n\t_snapshotB\t\n\x07_app_idB\x0c\n\n_stream_id\"F\n\x06\x41ppReq\x12\x13\n\x06\x61pp_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x63hunk\x18\x02 \x01(\x0cH\x01\x88\x01\x01\x42\t\n\x07_app_idB\x08\n\x06_chunk\"\x18\n\x06\x41ppRes\x12\x0e\n\x06result\x18\x01 \x01(\x08\"%\n\x07\x41ppList\x12\x1a\n\x03\x61pp\x18\x01 \x03(\x0b\x32\r.autocare.App\":\n\rInferenceList\x12)\n\tinference\x18\x01 \x03(\x0b\x32\x16.autocare.InferenceReq\"=\n\x10InferenceResList\x12)\n\tinference\x18\x01 \x03(\x0b\x32\x16.autocare.InferenceRes\"H\n\x06LicReq\x12\x10\n\x03key\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x16\n\thash_code\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x06\n\x04_keyB\x0c\n\n_hash_code\">\n\x06LicRes\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x16\n\thash_code\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_hash_code\"P\n\x0cStreamingReq\x12\x10\n\x03uri\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x17\n\nsession_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x06\n\x04_uriB\r\n\x0b_session_id\"~\n\x0cStreamingRes\x12\x15\n\x08location\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08ts_start\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x17\n\nsession_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_locationB\x0b\n\t_ts_startB\r\n\x0b_session_id\"\xd4\x01\n\x05Model\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x10\n\x08platform\x18\x04 \x01(\t\x12\x11\n\tframework\x18\x05 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x06 \x01(\x05\x12\x11\n\tprecision\x18\x07 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x08 \x01(\t\x12\x0c\n\x04path\x18\t \x01(\t\x12\x14\n\x0c\x63ompute_capa\x18\n \x01(\t\x12\x16\n\tref_count\x18\x0b \x01(\x05H\x00\x88\x01\x01\x42\x0c\n\n_ref_count\"\x9d\x01\n\x05\x45vent\x12\x13\n\x0b\x63\x61tegory_id\x18\x01 \x01(\t\x12\x15\n\rcategory_name\x18\x02 \x01(\t\x12\'\n\x07targets\x18\x03 \x03(\x0b\x32\x16.autocare.Event.Target\x1a?\n\x06Target\x12\x12\n\nevent_name\x18\x01 \x01(\t\x12\x10\n\x08\x65vent_id\x18\x02 \x01(\t\x12\x0f\n\x07\x63lasses\x18\x03 \x03(\t\"]\n\x08Pipeline\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06plugin\x18\x02 \x01(\t\x12\x15\n\x08model_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x0f\n\x07\x63lasses\x18\x04 \x03(\tB\x0b\n\t_model_id\"\xe7\x02\n\x03\x41pp\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\nevgen_path\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1f\n\x06models\x18\x04 \x03(\x0b\x32\x0f.autocare.Model\x12\x13\n\x06\x65vents\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x11\n\tpipelines\x18\x06 \x01(\t\x12\x17\n\ncover_path\x18\x07 \x01(\tH\x02\x88\x01\x01\x12\x0c\n\x04\x64\x65sc\x18\x08 \x01(\t\x12\x19\n\x0cmemory_usage\x18\t \x01(\x05H\x03\x88\x01\x01\x12\x14\n\x07version\x18\n \x01(\tH\x04\x88\x01\x01\x12\x16\n\tframework\x18\x0b \x01(\tH\x05\x88\x01\x01\x12\x14\n\x07outputs\x18\x0c \x01(\tH\x06\x88\x01\x01\x42\r\n\x0b_evgen_pathB\t\n\x07_eventsB\r\n\x0b_cover_pathB\x0f\n\r_memory_usageB\n\n\x08_versionB\x0c\n\n_frameworkB\n\n\x08_outputs\"\xb1\x01\n\x02\x44x\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61pacity\x18\x04 \x01(\x05\x12\x11\n\tactivated\x18\x05 \x01(\x05\x12\x0f\n\x07version\x18\x06 \x01(\t\x12\x11\n\tframework\x18\x07 \x01(\t\x12\x10\n\x08lic_type\x18\x08 \x01(\t\x12\x14\n\x0clic_end_date\x18\t \x01(\t\x12\x0f\n\x07lic_key\x18\n \x01(\t2\xb6\x08\n\x08\x44\x65tector\x12@\n\x0c\x41\x64\x64Inference\x12\x16.autocare.InferenceReq\x1a\x16.autocare.InferenceRes\"\x00\x12\x43\n\x0fRemoveInference\x12\x16.autocare.InferenceReq\x1a\x16.autocare.InferenceRes\"\x00\x12:\n\x12RemoveInferenceAll\x12\x10.autocare.AppReq\x1a\x10.autocare.AppRes\"\x00\x12\x43\n\x0fUpdateInference\x12\x16.autocare.InferenceReq\x1a\x16.autocare.InferenceRes\"\x00\x12\x34\n\nInstallApp\x12\x10.autocare.AppReq\x1a\x10.autocare.AppRes\"\x00(\x01\x12\x34\n\x0cUninstallApp\x12\x10.autocare.AppReq\x1a\x10.autocare.AppRes\"\x00\x12\x33\n\nGetAppList\x12\x10.autocare.AppReq\x1a\x11.autocare.AppList\"\x00\x12\x45\n\x10GetInferenceList\x12\x16.autocare.InferenceReq\x1a\x17.autocare.InferenceList\"\x00\x12\x46\n\x12GetInferenceStatus\x12\x16.autocare.InferenceReq\x1a\x16.autocare.InferenceRes\"\x00\x12G\n\x15GetInferenceStatusAll\x12\x10.autocare.AppReq\x1a\x1a.autocare.InferenceResList\"\x00\x12G\n\x13RequestPreviewImage\x12\x16.autocare.InferenceReq\x1a\x16.autocare.InferenceRes\"\x00\x12\x39\n\x11LicenseActivation\x12\x10.autocare.LicReq\x1a\x10.autocare.LicRes\"\x00\x12;\n\x13LicenseDeactivation\x12\x10.autocare.LicReq\x1a\x10.autocare.LicRes\"\x00\x12\x37\n\x0fLicenseActivate\x12\x10.autocare.LicReq\x1a\x10.autocare.LicRes\"\x00\x12\x42\n\x0eStartStreaming\x12\x16.autocare.StreamingReq\x1a\x16.autocare.StreamingRes\"\x00\x12\x41\n\rStopStreaming\x12\x16.autocare.StreamingReq\x1a\x16.autocare.StreamingRes\"\x00\x12(\n\x05GetDx\x12\x0f.autocare.Empty\x1a\x0c.autocare.Dx\"\x00\x42\x0f\xaa\x02\x0cGrpcDxClientb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dx_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\252\002\014GrpcDxClient'
  _globals['_EMPTY']._serialized_start=22
  _globals['_EMPTY']._serialized_end=29
  _globals['_PIPELINEREQ']._serialized_start=31
  _globals['_PIPELINEREQ']._serialized_end=60
  _globals['_PIPELINERES']._serialized_start=62
  _globals['_PIPELINERES']._serialized_end=91
  _globals['_INFERENCEREQ']._serialized_start=94
  _globals['_INFERENCEREQ']._serialized_end=284
  _globals['_INFERENCERES']._serialized_start=287
  _globals['_INFERENCERES']._serialized_end=534
  _globals['_APPREQ']._serialized_start=536
  _globals['_APPREQ']._serialized_end=606
  _globals['_APPRES']._serialized_start=608
  _globals['_APPRES']._serialized_end=632
  _globals['_APPLIST']._serialized_start=634
  _globals['_APPLIST']._serialized_end=671
  _globals['_INFERENCELIST']._serialized_start=673
  _globals['_INFERENCELIST']._serialized_end=731
  _globals['_INFERENCERESLIST']._serialized_start=733
  _globals['_INFERENCERESLIST']._serialized_end=794
  _globals['_LICREQ']._serialized_start=796
  _globals['_LICREQ']._serialized_end=868
  _globals['_LICRES']._serialized_start=870
  _globals['_LICRES']._serialized_end=932
  _globals['_STREAMINGREQ']._serialized_start=934
  _globals['_STREAMINGREQ']._serialized_end=1014
  _globals['_STREAMINGRES']._serialized_start=1016
  _globals['_STREAMINGRES']._serialized_end=1142
  _globals['_MODEL']._serialized_start=1145
  _globals['_MODEL']._serialized_end=1357
  _globals['_EVENT']._serialized_start=1360
  _globals['_EVENT']._serialized_end=1517
  _globals['_EVENT_TARGET']._serialized_start=1454
  _globals['_EVENT_TARGET']._serialized_end=1517
  _globals['_PIPELINE']._serialized_start=1519
  _globals['_PIPELINE']._serialized_end=1612
  _globals['_APP']._serialized_start=1615
  _globals['_APP']._serialized_end=1974
  _globals['_DX']._serialized_start=1977
  _globals['_DX']._serialized_end=2154
  _globals['_DETECTOR']._serialized_start=2157
  _globals['_DETECTOR']._serialized_end=3235
# @@protoc_insertion_point(module_scope)
